%define rname neon

%define	major		27
%define libname		%mklibname %{rname} %{major}
%define devname		%mklibname %{rname} -d
%define staticname	%mklibname %{rname} -d -s

%bcond_without	libproxy

Summary: 	An HTTP and WebDAV client library, with a C interface
Name: 		libneon
Version: 	0.33.0
Release: 	%mkrel 1
Group: 		Development/Other
License: 	GPLv2+ and LGPLv2+
URL:		https://notroj.github.io/neon/
Source0:	https://notroj.github.io/neon/neon-%{version}.tar.gz
BuildRequires:	pkgconfig(openssl) >= 0.9.7
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(krb5)
BuildRequires:	rootcerts
BuildRequires:	pkgconfig(zlib)
%if %{with libproxy}
BuildRequires:	pkgconfig(libproxy-1.0)
%endif
BuildRequires:	libtool
BuildRequires:	autoconf
BuildRequires:	multiarch-utils >= 1.0.3

%description
neon is an HTTP and WebDAV client library for Unix systems,
with a C language API. It provides high-level interfaces to
HTTP/1.1 and WebDAV  methods, and a low-level interface to
HTTP request/response handling, allowing new methods to be
easily implemented.

%package i18n
Summary:	Internationalization and locale data for %{name}
Group:		System/Internationalization
BuildArch:	noarch

%description i18n
This package contains the internationalization and locale data for %{name}.

%package -n %{libname}
Summary:	Shared libraries for %{name}
Group:		System/Libraries
Requires:	rootcerts
Requires:	openssl >= 0.9.7
Requires:	%{name}-i18n >= %{version}

%description -n %{libname}
neon is an HTTP and WebDAV client library for Unix systems,
with a C language API. It provides high-level interfaces to
HTTP/1.1 and WebDAV  methods, and a low-level interface to
HTTP request/response handling, allowing new methods to be
easily implemented.

%package -n %{devname}
Summary:	Headers for developing programs that will use %{name}
Group:		Development/C++
Requires:	%{libname} = %{version}-%{release}
Provides:	libneon-devel = %{version}-%{release}
Provides:	neon-devel = %{version}-%{release}

%description -n	%{devname}
This package contains the headers that programmers will need to develop
applications which will use %{name}.

%package -n %{staticname}
Summary:	Static %{name} library
Group:		Development/C++
Requires:	%{devname} = %{version}-%{release}
Provides:	libneon-static-devel = %{version}-%{release}
Provides:	neon-static-devel = %{version}-%{release}
Obsoletes:	%{_lib}neon0.27-static-devel < 0.30.0

%description -n	%{staticname}
Static %{name} library.

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%serverbuild
%configure \
    --enable-shared \
    --enable-static \
    --with-ssl=openssl \
    --enable-threadsafe-ssl=posix \
    --with-ca-bundle=%{_sysconfdir}/pki/tls/certs/ca-bundle.crt \
%if %{with libproxy}
    --with-libproxy \
%else
    --without-libproxy \
%endif
    --with-libxml2

%make_build

%install
%make_install

cp src/README README.neon

# fix this
rm -rf %{buildroot}%{_docdir}

find %{buildroot} -name *.la -delete

%multiarch_binaries %{buildroot}%{_bindir}/neon-config

%find_lang %{rname}

%check
export TEST_QUIET=0
make check

%files i18n -f %{rname}.lang

%files -n %{libname}
%doc doc/*.txt README.neon
%license src/COPYING.LIB
%{_libdir}/lib*.so.%{major}{,.*}

%files -n %{devname}
%doc AUTHORS BUGS doc/html NEWS README.md THANKS TODO
%multiarch %{multiarch_bindir}/neon-config
%{_bindir}/neon-config
%{_libdir}/lib*.so
%{_libdir}/pkgconfig/neon.pc
%{_includedir}/neon/
%{_mandir}/man1/*
%{_mandir}/man3/*

%files -n %{staticname}
%{_libdir}/lib*.a


%changelog
* Wed Oct 02 2024 daviddavid <daviddavid> 0.33.0-1.mga10
+ Revision: 2102756
- new version: 0.33.0
- remove all old patches

* Sat Mar 19 2022 umeabot <umeabot> 0.31.2-3.mga9
+ Revision: 1799887
- Mageia 9 Mass Rebuild

* Sat Oct 02 2021 wally <wally> 0.31.2-2.mga9
+ Revision: 1747452
- rebuild for openssl 3.0.0

* Sat Feb 27 2021 tv <tv> 0.31.2-1.mga9
+ Revision: 1693080
- 0.31.2

* Thu Feb 13 2020 umeabot <umeabot> 0.30.2-3.mga8
+ Revision: 1514292
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Sun Sep 23 2018 umeabot <umeabot> 0.30.2-2.mga7
+ Revision: 1299034
- Mageia 7 Mass Rebuild

* Thu Aug 03 2017 guillomovitch <guillomovitch> 0.30.2-1.mga7
+ Revision: 1134387
- new version 0.30.2

* Wed Mar 02 2016 umeabot <umeabot> 0.30.1-2.mga6
+ Revision: 983595
- Rebuild for openssl

* Sun Jan 03 2016 luigiwalser <luigiwalser> 0.30.1-1.mga6
+ Revision: 918784
- 0.30.1

* Sat Nov 07 2015 pterjan <pterjan> 0.30.0-5.mga6
+ Revision: 898468
- Drop release in the dependency on the noarch i18n package

* Wed Oct 15 2014 umeabot <umeabot> 0.30.0-4.mga5
+ Revision: 746058
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.30.0-3.mga5
+ Revision: 681633
- Mageia 5 Mass Rebuild

* Sun Mar 09 2014 wally <wally> 0.30.0-2.mga5
+ Revision: 601577
- fix static devel pkg requires

* Sun Mar 09 2014 wally <wally> 0.30.0-1.mga5
+ Revision: 601508
- new version 0.30.0
- rename pkg as libneon
- fix lib pkg name and split out the locale data
- drop upstream applied patches
- clean .spec

* Sun Jan 05 2014 danf <danf> 0.29.6-4.mga4
+ Revision: 564718
- Worked around a glibc bug to allow the test suite to pass
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 0.29.6-3.mga3
+ Revision: 357821
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ guillomovitch <guillomovitch>
- spec cleanup

* Wed Jul 04 2012 shlomif <shlomif> 0.29.6-2.mga3
+ Revision: 267152
- Remove trailing space
- Fix/rebuild for OpenSSL 1.0.1

* Sun Nov 27 2011 tv <tv> 0.29.6-1.mga2
+ Revision: 172599
- new release

* Thu Oct 20 2011 obgr_seneca <obgr_seneca> 0.29.5-2.mga2
+ Revision: 156990
- Removed .la files

* Sun Jan 09 2011 blino <blino> 0.29.5-2.mga1
+ Revision: 3527
- remove old version checks and ldconfig scriptlets
- imported package libneon0.27

